==> enterprisemodules-ora_install-5.14.3.tar.gz: enterprisemodules-ora_install-5.14.3/tasks/apply_psu_db.rb <==
#!/opt/puppetlabs/puppet/bin/ruby
#
#
# See the file "LICENSE" for the full license governing this code.
#
#
require 'json'
require 'open3'
require 'puppet'
require 'time'

begin
  Puppet.initialize_settings
rescue Puppet::DevError
  # When run in Rspec, this is called multiple times
end

class ApplyPsuDb

  def self.run
    instance = self.new
    instance.run
  end

  def run()
    @starttime = Time.now.iso8601
    begin
      fetch_input()
      execute()
      output_message = @message.join("\n")
      output(0, output_message)
    rescue => e
      error_output(1, e.message, "enterprisemodules-ora_install/task-error")
    end
  end

  def fetch_input
    params        = JSON.parse(STDIN.read)
    #
    # Use loadpath specfied in the params
    #
    $LOAD_PATH << "#{params['_installdir']}/easy_type/lib"
    $LOAD_PATH << "#{params['_installdir']}/ora_install/lib"
    require 'easy_type'
    require 'puppet_x/enterprisemodules/ora_install/tasks'
    extend ::PuppetX::EnterpriseModules::OraInstall::Tasks

    #
    # Fetch paramters
    #
    @verbose      = params.fetch('verbose') { 'info' }
    @sid          = params.fetch('sid')
    @format       = params.fetch('format') { 'pretty' }
    @oracle_homes = Facter.value('ora_install_homes')
    @current_home = home_for_sid(@sid)
    @message      = []
    Puppet::Util::Log.level = @verbose
  end

  def report()
    puts @result.to_json
  end

  def execute
    command = "#{@current_home}/OPatch/datapatch -verbose"
    options = { :failonfail => true, :combine => true }
    result = Puppet::Util::Execution.execute("export ORACLE_HOME=#{@current_home};export PATH=#{@current_home}/bin:#{@current_home}/OPatch:$PATH;export ORACLE_SID=#{@sid};export LD_LIBRARY_PATH=#{@current_home}/lib;#{command}", :uid => os_user)
    log_msg result
  end

  def os_user
    uid = File.stat("#{@current_home}/bin/oracle").uid
    Etc.getpwuid(uid).name
  end

  def home_for_sid(sid)
    selected_home_info = @oracle_homes.select {|d| @oracle_homes[d].fetch('defined_sids'){[]}.include?(sid)}
    fail "No home found for sid #{sid}" if selected_home_info.empty?
    selected_home = selected_home_info.keys.first
    fail "Sid #{sid} must be running to apply PSU." unless selected_home_info[selected_home].fetch('running_sids') {[]}.include?(sid)
    selected_home
  end
end

ApplyPsuDb.run if __FILE__ == $0

==> enterprisemodules-ora_install-6.9.6.tar.gz: enterprisemodules-ora_install-6.9.6/tasks/apply_psu_db.rb <==
#!/opt/puppetlabs/puppet/bin/ruby
#
#
# See the file "LICENSE" for the full license governing this code.
#
#
require 'json'
require 'open3'
require 'puppet'
require 'time'

begin
  Puppet.initialize_settings
rescue Puppet::DevError
  # When run in Rspec, this is called multiple times
end

class ApplyPsuDb

  def self.run
    instance = self.new
    instance.run
  end

  def run()
    @starttime = Time.now.iso8601
    begin
      fetch_input()
      execute()
      output_message = @message.join("\n")
      output(0, output_message)
    rescue => e
      error_output(1, e.message, "enterprisemodules-ora_install/task-error")
    end
  end

  def fetch_input
    params        = JSON.parse(STDIN.read)
    #
    # Use loadpath specfied in the params
    #
    $LOAD_PATH << "#{params['_installdir']}/easy_type/lib"
    $LOAD_PATH << "#{params['_installdir']}/ora_install/lib"
    require 'easy_type'
    require 'puppet_x/enterprisemodules/ora_install/tasks'
    extend ::PuppetX::EnterpriseModules::OraInstall::Tasks

    #
    # Fetch paramters
    #
    @verbose      = params.fetch('verbose') { 'info' }
    @sid          = params.fetch('sid')
    @format       = params.fetch('format') { 'pretty' }
    @oracle_homes = Facter.value('ora_install_homes')
    @current_home = home_for_sid(@sid)
    @message      = []
    Puppet::Util::Log.level = @verbose
  end

  def report()
    puts @result.to_json
  end

  def execute
    command = "#{@current_home}/OPatch/datapatch -verbose"
    options = { :failonfail => true, :combine => true }
    result = Puppet::Util::Execution.execute("export ORACLE_HOME=#{@current_home};export PATH=#{@current_home}/bin:#{@current_home}/OPatch:$PATH;export ORACLE_SID=#{@sid};export LD_LIBRARY_PATH=#{@current_home}/lib;#{command}", :uid => os_user)
    log_msg result
  end

  def os_user
    uid = File.stat("#{@current_home}/bin/oracle").uid
    Etc.getpwuid(uid).name
  end

  def home_for_sid(sid)
    selected_home_info = @oracle_homes['defined_sids'].select {|d| @oracle_homes['defined_sids'].fetch(d){[]}.include?(sid)}
    fail "No home found for sid #{sid}" if selected_home_info.empty?
    selected_home = selected_home_info.keys.first
    fail "Sid #{sid} must be running to apply PSU." unless selected_home_info[selected_home].fetch('running_sids') {[]}.include?(sid)
    selected_home
  end
end

ApplyPsuDb.run if __FILE__ == $0
